@@ -88,7 +88,7 @@ type ScanOptions struct {
 	// severity is the level of severity of policy violations that should be reported
 	severity string
 
-	// verbose indicates whether to display all fields in default human readlbe output
+	// verbose indicates whether to display all fields in default human readable output
 	verbose bool
 
 	// showPassedRules indicates whether to display passed rules or not
@@ -96,6 +96,9 @@ type ScanOptions struct {
 
 	// nonRecursive enables recursive scan for the terraform iac provider
 	nonRecursive bool
+
+	// useTerraformCache provides ability to use terraform init local cache for modules rather than downloading them.
+	useTerraformCache bool
 }
 
 // NewScanOptions returns a new pointer to ScanOptions
@@ -181,7 +184,7 @@ func (s *ScanOptions) Run() error {
 
 	// create a new runtime executor for processing IaC
 	executor, err := runtime.NewExecutor(s.iacType, s.iacVersion, s.policyType,
-		s.iacFilePath, s.iacDirPath, s.policyPath, s.scanRules, s.skipRules, s.categories, s.severity, s.nonRecursive)
+		s.iacFilePath, s.iacDirPath, s.policyPath, s.scanRules, s.skipRules, s.categories, s.severity, s.nonRecursive, s.useTerraformCache)
 	if err != nil {
 		return err
 	}
@@ -193,7 +196,7 @@ func (s *ScanOptions) Run() error {
 	}
 
 	// set the ResourcePath to remoteURL if remote directory is scanned.
-	if s.remoteURL != "" {
+	if !s.configOnly && s.remoteURL != "" {
 		results.Violations.ViolationStore.Summary.ResourcePath = s.remoteURL
 	}
 
