@@ -12,6 +12,7 @@ func TestLoadIacFile(t *testing.T) {
 	table := []struct {
 		name      string
 		filePath  string
+		options   map[string]interface{}
 		kustomize KustomizeV3
 		typeOnly  bool
 		want      output.AllResourceConfigs
@@ -27,7 +28,7 @@ func TestLoadIacFile(t *testing.T) {
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			_, gotErr := tt.kustomize.LoadIacFile(tt.filePath)
+			_, gotErr := tt.kustomize.LoadIacFile(tt.filePath, tt.options)
 			if !reflect.DeepEqual(gotErr, tt.wantErr) {
 				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
 			} else if tt.typeOnly && (reflect.TypeOf(gotErr)) != reflect.TypeOf(tt.wantErr) {
