@@ -25,7 +25,7 @@ import (
 // LoadIacDir starts traversing from the given rootDir and traverses through
 // all the descendant modules present to create an output list of all the
 // resources present in rootDir and descendant modules
-func (*TfV12) LoadIacDir(absRootDir string, nonRecursive bool) (allResourcesConfig output.AllResourceConfigs, err error) {
+func (*TfV12) LoadIacDir(absRootDir string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
 	zap.S().Warn("There may be a few breaking changes while working with terraform v0.12 files. For further information, refer to https://github.com/accurics/terrascan/releases/v1.3.0")
-	return commons.NewTerraformDirectoryLoader(absRootDir, nonRecursive).LoadIacDir()
+	return commons.NewTerraformDirectoryLoader(absRootDir, options).LoadIacDir()
 }
