@@ -63,19 +63,21 @@ func TestLoadIacDir(t *testing.T) {
 	}
 
 	table := []struct {
-		name         string
-		dirPath      string
-		tfv15        TfV15
-		want         output.AllResourceConfigs
-		nonRecursive bool
-		wantErr      error
+		name    string
+		dirPath string
+		tfv15   TfV15
+		want    output.AllResourceConfigs
+		wantErr error
+		options map[string]interface{}
 	}{
 		{
-			name:         "invalid dirPath",
-			dirPath:      testDirPath1,
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      multierror.Append(fmt.Errorf(invalidDirErrStringTemplate, testDirPath1)),
+			name:    "invalid dirPath",
+			dirPath: testDirPath1,
+			tfv15:   TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: multierror.Append(fmt.Errorf(invalidDirErrStringTemplate, testDirPath1)),
 		},
 		{
 			name:    "invalid dirPath recursive",
@@ -84,11 +86,13 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr: multierror.Append(pathErr),
 		},
 		{
-			name:         "empty config",
-			dirPath:      testDirPath2,
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      multierror.Append(fmt.Errorf(invalidDirErrStringTemplate, testDirPath2)),
+			name:    "empty config",
+			dirPath: testDirPath2,
+			tfv15:   TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: multierror.Append(fmt.Errorf(invalidDirErrStringTemplate, testDirPath2)),
 		},
 		{
 			name:    "empty config recursive",
@@ -97,11 +101,13 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr: nilMultiErr,
 		},
 		{
-			name:         "incorrect module structure",
-			dirPath:      filepath.Join(testDataDir, "invalid-moduleconfigs"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      multierror.Append(fmt.Errorf("failed to build terraform allResourcesConfig")),
+			name:    "incorrect module structure",
+			dirPath: filepath.Join(testDataDir, "invalid-moduleconfigs"),
+			tfv15:   TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: multierror.Append(fmt.Errorf("failed to build terraform allResourcesConfig")),
 		},
 		{
 			name:    "incorrect module structure recursive",
@@ -111,11 +117,13 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr: multierror.Append(fmt.Errorf(errStringInvalidModuleConfigs), fmt.Errorf(errStringInvalidModuleConfigs)),
 		},
 		{
-			name:         "load invalid config dir",
-			dirPath:      testDataDir,
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      multierror.Append(fmt.Errorf(testErrorMessage)),
+			name:    "load invalid config dir",
+			dirPath: testDataDir,
+			tfv15:   TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: multierror.Append(fmt.Errorf(testErrorMessage)),
 		},
 		{
 			name:    "load invalid config dir recursive",
@@ -155,7 +163,7 @@ func TestLoadIacDir(t *testing.T) {
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			_, gotErr := tt.tfv15.LoadIacDir(tt.dirPath, tt.nonRecursive)
+			_, gotErr := tt.tfv15.LoadIacDir(tt.dirPath, tt.options)
 			me, ok := gotErr.(*multierror.Error)
 			if !ok {
 				t.Errorf("expected multierror.Error, got %T", gotErr)
@@ -175,20 +183,22 @@ func TestLoadIacDir(t *testing.T) {
 	nestedModuleErr2 := fmt.Errorf(invalidDirErrStringTemplate, filepath.Join(testDataDir, "deep-modules", "modules", "m4", "modules"))
 
 	table2 := []struct {
-		name         string
-		tfConfigDir  string
-		tfJSONFile   string
-		tfv15        TfV15
-		nonRecursive bool
-		wantErr      error
+		name        string
+		tfConfigDir string
+		tfJSONFile  string
+		tfv15       TfV15
+		wantErr     error
+		options     map[string]interface{}
 	}{
 		{
-			name:         "config1",
-			tfConfigDir:  filepath.Join(testDataDir, "tfconfigs"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "fullconfig.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "config1",
+			tfConfigDir: filepath.Join(testDataDir, "tfconfigs"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "fullconfig.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 		{
 			name:        "config1 recursive",
@@ -199,12 +209,14 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr:    nilMultiErr,
 		},
 		{
-			name:         "module directory",
-			tfConfigDir:  filepath.Join(testDataDir, "moduleconfigs"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "moduleconfigs.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "module directory",
+			tfConfigDir: filepath.Join(testDataDir, "moduleconfigs"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "moduleconfigs.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 		{
 			name:        "module directory recursive",
@@ -215,12 +227,14 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr:    nilMultiErr,
 		},
 		{
-			name:         "nested module directory",
-			tfConfigDir:  filepath.Join(testDataDir, "deep-modules"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "deep-modules.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "nested module directory",
+			tfConfigDir: filepath.Join(testDataDir, "deep-modules"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "deep-modules.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 		{
 			name:        "nested module directory recursive",
@@ -230,34 +244,40 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr:     multierror.Append(nestedModuleErr1, nestedModuleErr2),
 		},
 		{
-			name:         "complex variables",
-			tfConfigDir:  filepath.Join(testDataDir, "complex-variables"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "complex-variables.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "complex variables",
+			tfConfigDir: filepath.Join(testDataDir, "complex-variables"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "complex-variables.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 		{
-			name:         "recursive loop while resolving variables",
-			tfConfigDir:  filepath.Join(testDataDir, "recursive-loop-variables"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "recursive-loop-variables.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "recursive loop while resolving variables",
+			tfConfigDir: filepath.Join(testDataDir, "recursive-loop-variables"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "recursive-loop-variables.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 		{
-			name:         "recursive loop while resolving locals",
-			tfConfigDir:  filepath.Join(testDataDir, "recursive-loop-locals"),
-			tfJSONFile:   filepath.Join(tfJSONDir, "recursive-loop-locals.json"),
-			tfv15:        TfV15{},
-			nonRecursive: true,
-			wantErr:      nilMultiErr,
+			name:        "recursive loop while resolving locals",
+			tfConfigDir: filepath.Join(testDataDir, "recursive-loop-locals"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "recursive-loop-locals.json"),
+			tfv15:       TfV15{},
+			options: map[string]interface{}{
+				"nonRecursive": true,
+			},
+			wantErr: nilMultiErr,
 		},
 	}
 
 	for _, tt := range table2 {
 		t.Run(tt.name, func(t *testing.T) {
-			got, gotErr := tt.tfv15.LoadIacDir(tt.tfConfigDir, tt.nonRecursive)
+			got, gotErr := tt.tfv15.LoadIacDir(tt.tfConfigDir, tt.options)
 			me, ok := gotErr.(*multierror.Error)
 			if !ok {
 				t.Errorf("expected multierror.Error, got %T", gotErr)
